ANT CDE
=======

Provides access to ANT CDE.


Version 2.0.7rc19
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc18
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc17
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc16
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc15
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc14
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc13
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc12
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc11
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc10
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc9
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc8
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc7
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc6
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc5
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc4
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc3
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc2
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc1
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.7rc0
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.6
-----------------
- Automatically generated update of the package. Visit ANTCDE.io to find out more about what has changed


Version 2.0.6rc4
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.6rc3
-----------------
- Automatically generated release candidate, based on backend updates
- Improved the QueryBuilder class to handle nested queries
- Added a method called add_parameter to add a parameter with a value manually to the query string


Version 2.0.6rc0
-----------------
- Automatically generated release candidate, based on backend updates


Version 2.0.5
-----------------
- Automatically generated update of the package. Visit ANTCDE.io to find out more about what has changed


Version 2.0.5rc1
-----------------
- Automatically generated release candidate, based on backend updates
- improved the Document object to upload and download files
- bug fixes and improvements to models


Version 2.0.5rc0
-----------------
- Automatically generated release candidate, based on backend updates
- updated the package with the QueryBuilder class to create query strings (see documentation for more information)
- updated the package with the QueryOperator class (see documentation for more information)


Version 2.0.4
-----------------
- Added new methods to ant models
- Updated to latest ANT data model
- Added option to pass a custum config file to the ApiConnector


Version 2.0.3
-----------------
- Bug fixes for Python 3.8 users/developers
- Updated to latest ANT data model


Version 2.0.2
-----------------
- Bug fix in requirements


Version 2.0.1
-----------------
- Bug fix for Python 3.8 users
- Better, more extensive, docstrings
- Updated to latest ANT data model


Version 2.0.0
-----------------
- All new Python v2 ANT CDE Connect package
- V1 package included for backwards compatibility. `from ant_connect import v1 as ant_connect_v1`
- V2 package is the default. `from ant_connect import ApiConnector`
